@@ -78,15 +78,15 @@ def read(sock, get=True, data=False):
     else:
         msg_len = 4096
         
-    full = ''
+    full = b''
         
     while True:
         try:
             msg = sock.recv(msg_len)
-            full += msg.decode()
+            full += msg
             
-            if full[-2:] == '\r\n':
-                message['body'] = full[:-2]
+            if full.endswith('\r\n'.encode()):
+                message['body'] = full.decode()[:-2]
                 break
 
         except ConnectionAbortedError:
